==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/37/37be4a17ce3369afd6b8fd01443be33b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/aurora/assets/icon_social.png */
class __TwigTemplate_6e3e76f5ce1c304c8aaae1ad39782c53 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000P\000\000\000P\000\000\000\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000IDATx?L@ϦP3&X\t&Lb*PRDJN!\$J &.\tRjRKlǹ{)A\tlQhBHF+ZͬZ?::Vud`h/c3HWهwEe
][H`rx*m5
1'q[o \000j)1E#KQ7m:.ɆUhhGt=#0xTo1e?#~l+<S>1r?m۶\"肗v\to\$aIN4|~<7Vl2= 
kF8!۳#|x wo\tmeΣ^-\$t5ˋBfUx6qd=P{_p/|'#dhh=e7779[gggZy W?0xA wwwl9G\0001U(<Q\"RVo}}mxBVSa>mɫ(L<gV\\z^Ray
91.ell&40S,{ley\\XX\000T258S2?\000+SRɧ.R\tFS+j\"y_jF\000pXg؆M`lďUb%]\\Qpc``fff\\/]_G}zPA\$*6>>.xҗNtFRfFc?3\t
@\000uww3ХRA8xowt~JtDUMcbL3~+VevvVXg

޸͞#uRUhB r\$0#TV0%?@.--\tU&7r*ߓ0f3\tᘚeY9]*;s:qFnggS\"1fiM]PMG9qm(rsNTT+Nf
Pimk Vexcي[9p~4e:1 h\000ƪvЇ2>0Q\"k۶iBH,K0҇CvppEㅕU@S<N /\000D_.5
C5:iNB{49TPp}\\
}_h6!]>Qd&SVhk-4:kIbp,Vo[j)w7g7#_۞|ˌ\000|C}>*O%@; Iv/jec9qaıچ:_}rR
~}hIo>'u)Q9n\000c#:Ro!L\"Z p6Z*0/\000y\ts\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/aurora/assets/icon_social.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/aurora/assets/icon_social.png", "/var/www/html/mauticGIT-Test/themes/aurora/assets/icon_social.png");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/37/37be4a17ce3369afd6b8fd01443be33b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/aurora/assets/icon_social.png */
class __TwigTemplate_6e3e76f5ce1c304c8aaae1ad39782c53 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000P\000\000\000P\000\000\000\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000IDATx?L@ϦP3&X\t&Lb*PRDJN!\$J &.\tRjRKlǹ{)A\tlQhBHF+ZͬZ?::Vud`h/c3HWهwEe
][H`rx*m5
1'q[o \000j)1E#KQ7m:.ɆUhhGt=#0xTo1e?#~l+<S>1r?m۶\"肗v\to\$aIN4|~<7Vl2= 
kF8!۳#|x wo\tmeΣ^-\$t5ˋBfUx6qd=P{_p/|'#dhh=e7779[gggZy W?0xA wwwl9G\0001U(<Q\"RVo}}mxBVSa>mɫ(L<gV\\z^Ray
91.ell&40S,{ley\\XX\000T258S2?\000+SRɧ.R\tFS+j\"y_jF\000pXg؆M`lďUb%]\\Qpc``fff\\/]_G}zPA\$*6>>.xҗNtFRfFc?3\t
@\000uww3ХRA8xowt~JtDUMcbL3~+VevvVXg

޸͞#uRUhB r\$0#TV0%?@.--\tU&7r*ߓ0f3\tᘚeY9]*;s:qFnggS\"1fiM]PMG9qm(rsNTT+Nf
Pimk Vexcي[9p~4e:1 h\000ƪvЇ2>0Q\"k۶iBH,K0҇CvppEㅕU@S<N /\000D_.5
C5:iNB{49TPp}\\
}_h6!]>Qd&SVhk-4:kIbp,Vo[j)w7g7#_۞|ˌ\000|C}>*O%@; Iv/jec9qaıچ:_}rR
~}hIo>'u)Q9n\000c#:Ro!L\"Z p6Z*0/\000y\ts\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/aurora/assets/icon_social.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/aurora/assets/icon_social.png", "/var/www/html/production-demo/themes/aurora/assets/icon_social.png");
    }
}
